Class: Google::Cloud::PolicySimulator::V1::ExplainedAccess
- Inherits:
-
Object
- Object
- Google::Cloud::PolicySimulator::V1::ExplainedAccess
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/policysimulator/v1/simulator.rb
Overview
Details about how a set of policies, listed in ExplainedPolicy, resulted in a certain AccessState when replaying an access tuple.
Instance Attribute Summary collapse
-
#access_state ⇒ ::Google::Cloud::PolicySimulator::V1::AccessState
Whether the principal in the access tuple has permission to access the resource in the access tuple under the given policies.
-
#errors ⇒ ::Array<::Google::Rpc::Status>
If the AccessState is
UNKNOWN, this field contains a list of errors explaining why the result isUNKNOWN. -
#policies ⇒ ::Array<::Google::Cloud::PolicySimulator::V1::ExplainedPolicy>
If the AccessState is
UNKNOWN, this field contains the policies that led to that result.
Instance Attribute Details
#access_state ⇒ ::Google::Cloud::PolicySimulator::V1::AccessState
Returns Whether the principal in the access tuple has permission to access the resource in the access tuple under the given policies.
393 394 395 396 |
# File 'proto_docs/google/cloud/policysimulator/v1/simulator.rb', line 393 class ExplainedAccess include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#errors ⇒ ::Array<::Google::Rpc::Status>
Returns If the AccessState is
UNKNOWN, this field contains a list of errors explaining why the result
is UNKNOWN.
If the AccessState is GRANTED or NOT_GRANTED, this field is
omitted.
393 394 395 396 |
# File 'proto_docs/google/cloud/policysimulator/v1/simulator.rb', line 393 class ExplainedAccess include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#policies ⇒ ::Array<::Google::Cloud::PolicySimulator::V1::ExplainedPolicy>
Returns If the AccessState is
UNKNOWN, this field contains the policies that led to that result.
If the AccessState is GRANTED or NOT_GRANTED, this field is
omitted.
393 394 395 396 |
# File 'proto_docs/google/cloud/policysimulator/v1/simulator.rb', line 393 class ExplainedAccess include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |