Class: Google::Cloud::PolicySimulator::V1::ListOrgPolicyViolationsPreviewsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb

Overview

ListOrgPolicyViolationsPreviewsRequest is the request message for OrgPolicyViolationsPreviewService.ListOrgPolicyViolationsPreviews.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Optional. The maximum number of items to return. The service may return fewer than this value. If unspecified, at most 5 items will be returned. The maximum value is 10; values above 10 will be coerced to 10.

Returns:

  • (::Integer)

    Optional. The maximum number of items to return. The service may return fewer than this value. If unspecified, at most 5 items will be returned. The maximum value is 10; values above 10 will be coerced to 10.



260
261
262
263
# File 'proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb', line 260

class ListOrgPolicyViolationsPreviewsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous call. Provide this to retrieve the subsequent page.

When paginating, all other parameters must match the call that provided the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters must match the call that provided the page token.



260
261
262
263
# File 'proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb', line 260

class ListOrgPolicyViolationsPreviewsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent the violations are scoped to. Format: organizations/{organization}/locations/{location}

Example: organizations/my-example-org/locations/global.

Returns:

  • (::String)

    Required. The parent the violations are scoped to. Format: organizations/{organization}/locations/{location}

    Example: organizations/my-example-org/locations/global



260
261
262
263
# File 'proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb', line 260

class ListOrgPolicyViolationsPreviewsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end