Class: Google::Cloud::PolicySimulator::V1::ListOrgPolicyViolationsPreviewsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb

Overview

ListOrgPolicyViolationsPreviewsResponse is the response message for OrgPolicyViolationsPreviewService.ListOrgPolicyViolationsPreviews.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token that you can use to retrieve the next page of results. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token that you can use to retrieve the next page of results. If this field is omitted, there are no subsequent pages.



274
275
276
277
# File 'proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb', line 274

class ListOrgPolicyViolationsPreviewsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#org_policy_violations_previews::Array<::Google::Cloud::PolicySimulator::V1::OrgPolicyViolationsPreview>

Returns The list of OrgPolicyViolationsPreview.

Returns:



274
275
276
277
# File 'proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb', line 274

class ListOrgPolicyViolationsPreviewsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end