Class: Google::Cloud::PolicySimulator::V1::ListOrgPolicyViolationsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb

Overview

ListOrgPolicyViolationsRequest is the request message for OrgPolicyViolationsPreviewService.ListOrgPolicyViolations.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Optional. The maximum number of items to return. The service may return fewer than this value. If unspecified, at most 1000 items will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    Optional. The maximum number of items to return. The service may return fewer than this value. If unspecified, at most 1000 items will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.



332
333
334
335
# File 'proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb', line 332

class ListOrgPolicyViolationsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous call. Provide this to retrieve the subsequent page.

When paginating, all other parameters must match the call that provided the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters must match the call that provided the page token.



332
333
334
335
# File 'proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb', line 332

class ListOrgPolicyViolationsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The OrgPolicyViolationsPreview to get OrgPolicyViolations from. Format: organizations/{organization}/locations/{location}/orgPolicyViolationsPreviews/{orgPolicyViolationsPreview}.

Returns:

  • (::String)

    Required. The OrgPolicyViolationsPreview to get OrgPolicyViolations from. Format: organizations/{organization}/locations/{location}/orgPolicyViolationsPreviews/{orgPolicyViolationsPreview}



332
333
334
335
# File 'proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb', line 332

class ListOrgPolicyViolationsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end