Class: Google::Cloud::PolicySimulator::V1::ListOrgPolicyViolationsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb

Overview

ListOrgPolicyViolationsResponse is the response message for OrgPolicyViolationsPreviewService.ListOrgPolicyViolations

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token that you can use to retrieve the next page of results. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token that you can use to retrieve the next page of results. If this field is omitted, there are no subsequent pages.



346
347
348
349
# File 'proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb', line 346

class ListOrgPolicyViolationsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#org_policy_violations::Array<::Google::Cloud::PolicySimulator::V1::OrgPolicyViolation>

Returns The list of OrgPolicyViolations.

Returns:



346
347
348
349
# File 'proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb', line 346

class ListOrgPolicyViolationsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end