Class: Google::Cloud::PolicySimulator::V1::OrgPolicyOverlay::PolicyOverlay

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb

Overview

A change to an OrgPolicy.

Instance Attribute Summary collapse

Instance Attribute Details

#policy::Google::Cloud::OrgPolicy::V2::Policy

Returns Optional. The new or updated OrgPolicy.

Returns:



193
194
195
196
# File 'proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb', line 193

class PolicyOverlay
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#policy_parent::String

Returns Optional. The parent of the policy we are attaching to. Example: "projects/123456".

Returns:

  • (::String)

    Optional. The parent of the policy we are attaching to. Example: "projects/123456"



193
194
195
196
# File 'proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb', line 193

class PolicyOverlay
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end