Class: Google::Cloud::PolicySimulator::V1::OrgPolicyViolationsPreview::ResourceCounts
- Inherits:
-
Object
- Object
- Google::Cloud::PolicySimulator::V1::OrgPolicyViolationsPreview::ResourceCounts
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb
Overview
A summary of the state of all resources scanned for compliance with the changed OrgPolicy.
Instance Attribute Summary collapse
-
#compliant ⇒ ::Integer
readonly
Output only.
-
#errors ⇒ ::Integer
readonly
Output only.
-
#noncompliant ⇒ ::Integer
readonly
Output only.
-
#scanned ⇒ ::Integer
readonly
Output only.
-
#unenforced ⇒ ::Integer
readonly
Output only.
Instance Attribute Details
#compliant ⇒ ::Integer (readonly)
Returns Output only. Number of scanned resources with zero violations.
100 101 102 103 |
# File 'proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb', line 100 class ResourceCounts include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#errors ⇒ ::Integer (readonly)
Returns Output only. Number of resources that returned an error when scanned.
100 101 102 103 |
# File 'proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb', line 100 class ResourceCounts include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#noncompliant ⇒ ::Integer (readonly)
Returns Output only. Number of scanned resources with at least one violation.
100 101 102 103 |
# File 'proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb', line 100 class ResourceCounts include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#scanned ⇒ ::Integer (readonly)
Returns Output only. Number of resources checked for compliance.
Must equal: unenforced + noncompliant + compliant + error.
100 101 102 103 |
# File 'proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb', line 100 class ResourceCounts include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unenforced ⇒ ::Integer (readonly)
Returns Output only. Number of resources where the constraint was not enforced,
i.e. the Policy set enforced: false for that resource.
100 101 102 103 |
# File 'proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb', line 100 class ResourceCounts include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |