Module: Google::Cloud::PolicySimulator::V1::OrgPolicyViolationsPreviewService

Defined in:
lib/google/cloud/policy_simulator/v1/org_policy_violations_preview_service.rb,
lib/google/cloud/policy_simulator/v1/org_policy_violations_preview_service/rest.rb,
lib/google/cloud/policy_simulator/v1/org_policy_violations_preview_service/paths.rb,
lib/google/cloud/policy_simulator/v1/org_policy_violations_preview_service/client.rb,
lib/google/cloud/policy_simulator/v1/org_policy_violations_preview_service/operations.rb,
lib/google/cloud/policy_simulator/v1/org_policy_violations_preview_service/credentials.rb,
lib/google/cloud/policy_simulator/v1/org_policy_violations_preview_service/rest/client.rb,
lib/google/cloud/policy_simulator/v1/org_policy_violations_preview_service/rest/operations.rb,
lib/google/cloud/policy_simulator/v1/org_policy_violations_preview_service/rest/service_stub.rb

Overview

Violations Preview API service for OrgPolicy.

An OrgPolicyViolationsPreview is a preview of the violations that will exist as soon as a proposed OrgPolicy change is submitted. To create an OrgPolicyViolationsPreview, the API user specifies the changes they wish to make and requests the generation of a preview via [GenerateViolationsPreview][]. the OrgPolicy Simulator service then scans the API user's currently existing resources to determine these resources violate the newly set OrgPolicy.

To load this service and instantiate a REST client:

require "google/cloud/policy_simulator/v1/org_policy_violations_preview_service/rest"
client = ::Google::Cloud::PolicySimulator::V1::OrgPolicyViolationsPreviewService::Rest::Client.new

Defined Under Namespace

Modules: Paths, Rest Classes: Client, Credentials, Operations