Class: Google::Cloud::PolicySimulator::V1::ResourceContext

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb

Overview

ResourceContext provides the context we know about a resource. It is similar in concept to google.cloud.asset.v1.Resource, but focuses on the information specifically used by Simulator.

Instance Attribute Summary collapse

Instance Attribute Details

#ancestors::Array<::String>

Returns The ancestry path of the resource in Google Cloud resource hierarchy, represented as a list of relative resource names. An ancestry path starts with the closest ancestor in the hierarchy and ends at root. If the resource is a project, folder, or organization, the ancestry path starts from the resource itself.

Example: ["projects/123456789", "folders/5432", "organizations/1234"].

Returns:

  • (::Array<::String>)

    The ancestry path of the resource in Google Cloud resource hierarchy, represented as a list of relative resource names. An ancestry path starts with the closest ancestor in the hierarchy and ends at root. If the resource is a project, folder, or organization, the ancestry path starts from the resource itself.

    Example: ["projects/123456789", "folders/5432", "organizations/1234"]



156
157
158
159
# File 'proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb', line 156

class ResourceContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#asset_type::String

Returns The asset type of the resource as defined by CAIS.

Example: compute.googleapis.com/Firewall

See Supported asset types for more information.

Returns:

  • (::String)

    The asset type of the resource as defined by CAIS.

    Example: compute.googleapis.com/Firewall

    See Supported asset types for more information.



156
157
158
159
# File 'proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb', line 156

class ResourceContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#resource::String

Returns The full name of the resource. Example: //compute.googleapis.com/projects/my_project_123/zones/zone1/instances/instance1

See Resource names for more information.

Returns:

  • (::String)

    The full name of the resource. Example: //compute.googleapis.com/projects/my_project_123/zones/zone1/instances/instance1

    See Resource names for more information.



156
157
158
159
# File 'proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb', line 156

class ResourceContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end