Class: Google::Cloud::PolicySimulator::V1::OrgPolicyOverlay
- Inherits:
-
Object
- Object
- Google::Cloud::PolicySimulator::V1::OrgPolicyOverlay
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb
Overview
The proposed changes to OrgPolicy.
Defined Under Namespace
Classes: CustomConstraintOverlay, PolicyOverlay
Instance Attribute Summary collapse
-
#custom_constraints ⇒ ::Array<::Google::Cloud::PolicySimulator::V1::OrgPolicyOverlay::CustomConstraintOverlay>
Optional.
-
#policies ⇒ ::Array<::Google::Cloud::PolicySimulator::V1::OrgPolicyOverlay::PolicyOverlay>
Optional.
Instance Attribute Details
#custom_constraints ⇒ ::Array<::Google::Cloud::PolicySimulator::V1::OrgPolicyOverlay::CustomConstraintOverlay>
Returns Optional. The OrgPolicy CustomConstraint changes to preview violations for.
Any existing CustomConstraints with the same name will be overridden in the simulation. That is, violations will be determined as if all custom constraints in the overlay were instantiated.
Only a single custom_constraint is supported in the overlay at a time.
For evaluating multiple constraints, multiple
GenerateOrgPolicyViolationsPreview requests are made, where each request
evaluates a single constraint.
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb', line 181 class OrgPolicyOverlay include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A change to an OrgPolicy. # @!attribute [rw] policy_parent # @return [::String] # Optional. The parent of the policy we are attaching to. # Example: "projects/123456" # @!attribute [rw] policy # @return [::Google::Cloud::OrgPolicy::V2::Policy] # Optional. The new or updated OrgPolicy. class PolicyOverlay include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A change to an OrgPolicy custom constraint. # @!attribute [rw] custom_constraint_parent # @return [::String] # Optional. Resource the constraint is attached to. # Example: "organization/987654" # @!attribute [rw] custom_constraint # @return [::Google::Cloud::OrgPolicy::V2::CustomConstraint] # Optional. The new or updated custom constraint. class CustomConstraintOverlay include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#policies ⇒ ::Array<::Google::Cloud::PolicySimulator::V1::OrgPolicyOverlay::PolicyOverlay>
Returns Optional. The OrgPolicy changes to preview violations for.
Any existing OrgPolicies with the same name will be overridden in the simulation. That is, violations will be determined as if all policies in the overlay were created or updated.
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'proto_docs/google/cloud/policysimulator/v1/orgpolicy.rb', line 181 class OrgPolicyOverlay include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A change to an OrgPolicy. # @!attribute [rw] policy_parent # @return [::String] # Optional. The parent of the policy we are attaching to. # Example: "projects/123456" # @!attribute [rw] policy # @return [::Google::Cloud::OrgPolicy::V2::Policy] # Optional. The new or updated OrgPolicy. class PolicyOverlay include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A change to an OrgPolicy custom constraint. # @!attribute [rw] custom_constraint_parent # @return [::String] # Optional. Resource the constraint is attached to. # Example: "organization/987654" # @!attribute [rw] custom_constraint # @return [::Google::Cloud::OrgPolicy::V2::CustomConstraint] # Optional. The new or updated custom constraint. class CustomConstraintOverlay include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |