Class: Google::Cloud::PolicySimulator::V1::OrgPolicyViolationsPreviewService::Rest::Client
- Inherits:
-
Object
- Object
- Google::Cloud::PolicySimulator::V1::OrgPolicyViolationsPreviewService::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/policy_simulator/v1/org_policy_violations_preview_service/rest/client.rb
Overview
REST client for the OrgPolicyViolationsPreviewService service.
Violations Preview API service for OrgPolicy.
An OrgPolicyViolationsPreview is a preview of the violations that will exist as soon as a proposed OrgPolicy change is submitted. To create an OrgPolicyViolationsPreview, the API user specifies the changes they wish to make and requests the generation of a preview via [GenerateViolationsPreview][]. the OrgPolicy Simulator service then scans the API user's currently existing resources to determine these resources violate the newly set OrgPolicy.
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#operations_client ⇒ ::Google::Cloud::PolicySimulator::V1::OrgPolicyViolationsPreviewService::Rest::Operations
readonly
Get the associated client for long-running operations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the OrgPolicyViolationsPreviewService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the OrgPolicyViolationsPreviewService Client instance.
-
#create_org_policy_violations_preview(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Operation
CreateOrgPolicyViolationsPreview creates an OrgPolicyViolationsPreview for the proposed changes in the provided [OrgPolicyViolationsPreview.OrgPolicyOverlay][].
-
#get_org_policy_violations_preview(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::PolicySimulator::V1::OrgPolicyViolationsPreview
GetOrgPolicyViolationsPreview gets the specified OrgPolicyViolationsPreview.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new OrgPolicyViolationsPreviewService REST client object.
-
#list_org_policy_violations(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::PolicySimulator::V1::OrgPolicyViolation>
ListOrgPolicyViolations lists the [OrgPolicyViolations][] that are present in an OrgPolicyViolationsPreview.
-
#list_org_policy_violations_previews(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::PolicySimulator::V1::OrgPolicyViolationsPreview>
ListOrgPolicyViolationsPreviews lists each OrgPolicyViolationsPreview in an organization.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
Methods included from Paths
#custom_constraint_path, #org_policy_violations_preview_path, #organization_location_path, #policy_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new OrgPolicyViolationsPreviewService REST client object.
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/google/cloud/policy_simulator/v1/org_policy_violations_preview_service/rest/client.rb', line 153 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @operations_client = ::Google::Cloud::PolicySimulator::V1::OrgPolicyViolationsPreviewService::Rest::Operations.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @config.endpoint config.universe_domain = @config.universe_domain end @org_policy_violations_preview_service_stub = ::Google::Cloud::PolicySimulator::V1::OrgPolicyViolationsPreviewService::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @org_policy_violations_preview_service_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Instance Attribute Details
#operations_client ⇒ ::Google::Cloud::PolicySimulator::V1::OrgPolicyViolationsPreviewService::Rest::Operations (readonly)
Get the associated client for long-running operations.
207 208 209 |
# File 'lib/google/cloud/policy_simulator/v1/org_policy_violations_preview_service/rest/client.rb', line 207 def operations_client @operations_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the OrgPolicyViolationsPreviewService Client class.
See Configuration for a description of the configuration fields.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/google/cloud/policy_simulator/v1/org_policy_violations_preview_service/rest/client.rb', line 74 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "PolicySimulator", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.list_org_policy_violations_previews.timeout = 60.0 default_config.rpcs.list_org_policy_violations_previews.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.get_org_policy_violations_preview.timeout = 60.0 default_config.rpcs.get_org_policy_violations_preview.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.create_org_policy_violations_preview.timeout = 60.0 default_config.rpcs.list_org_policy_violations.timeout = 60.0 default_config.rpcs.list_org_policy_violations.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the OrgPolicyViolationsPreviewService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
123 124 125 126 |
# File 'lib/google/cloud/policy_simulator/v1/org_policy_violations_preview_service/rest/client.rb', line 123 def configure yield @config if block_given? @config end |
#create_org_policy_violations_preview(request, options = nil) ⇒ ::Gapic::Operation #create_org_policy_violations_preview(parent: nil, org_policy_violations_preview: nil, org_policy_violations_preview_id: nil) ⇒ ::Gapic::Operation
CreateOrgPolicyViolationsPreview creates an
OrgPolicyViolationsPreview
for the proposed changes in the provided
[OrgPolicyViolationsPreview.OrgPolicyOverlay][]. The changes to OrgPolicy
are specified by this OrgPolicyOverlay. The resources to scan are
inferred from these specified changes.
471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 |
# File 'lib/google/cloud/policy_simulator/v1/org_policy_violations_preview_service/rest/client.rb', line 471 def create_org_policy_violations_preview request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::PolicySimulator::V1::CreateOrgPolicyViolationsPreviewRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_org_policy_violations_preview..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::PolicySimulator::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.create_org_policy_violations_preview.timeout, metadata: , retry_policy: @config.rpcs.create_org_policy_violations_preview.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @org_policy_violations_preview_service_stub.create_org_policy_violations_preview request, do |result, operation| result = ::Gapic::Operation.new result, @operations_client, options: yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_org_policy_violations_preview(request, options = nil) ⇒ ::Google::Cloud::PolicySimulator::V1::OrgPolicyViolationsPreview #get_org_policy_violations_preview(name: nil) ⇒ ::Google::Cloud::PolicySimulator::V1::OrgPolicyViolationsPreview
GetOrgPolicyViolationsPreview gets the specified OrgPolicyViolationsPreview. Each OrgPolicyViolationsPreview is available for at least 7 days.
369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/google/cloud/policy_simulator/v1/org_policy_violations_preview_service/rest/client.rb', line 369 def get_org_policy_violations_preview request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::PolicySimulator::V1::GetOrgPolicyViolationsPreviewRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_org_policy_violations_preview..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::PolicySimulator::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_org_policy_violations_preview.timeout, metadata: , retry_policy: @config.rpcs.get_org_policy_violations_preview.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @org_policy_violations_preview_service_stub.get_org_policy_violations_preview request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_org_policy_violations(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::PolicySimulator::V1::OrgPolicyViolation> #list_org_policy_violations(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::PolicySimulator::V1::OrgPolicyViolation>
ListOrgPolicyViolations lists the [OrgPolicyViolations][] that are present in an OrgPolicyViolationsPreview.
569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 |
# File 'lib/google/cloud/policy_simulator/v1/org_policy_violations_preview_service/rest/client.rb', line 569 def list_org_policy_violations request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::PolicySimulator::V1::ListOrgPolicyViolationsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_org_policy_violations..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::PolicySimulator::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_org_policy_violations.timeout, metadata: , retry_policy: @config.rpcs.list_org_policy_violations.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @org_policy_violations_preview_service_stub.list_org_policy_violations request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @org_policy_violations_preview_service_stub, :list_org_policy_violations, "org_policy_violations", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_org_policy_violations_previews(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::PolicySimulator::V1::OrgPolicyViolationsPreview> #list_org_policy_violations_previews(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::PolicySimulator::V1::OrgPolicyViolationsPreview>
ListOrgPolicyViolationsPreviews lists each OrgPolicyViolationsPreview in an organization. Each OrgPolicyViolationsPreview is available for at least 7 days.
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/google/cloud/policy_simulator/v1/org_policy_violations_preview_service/rest/client.rb', line 285 def list_org_policy_violations_previews request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::PolicySimulator::V1::ListOrgPolicyViolationsPreviewsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_org_policy_violations_previews..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::PolicySimulator::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_org_policy_violations_previews.timeout, metadata: , retry_policy: @config.rpcs.list_org_policy_violations_previews.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @org_policy_violations_preview_service_stub.list_org_policy_violations_previews request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @org_policy_violations_preview_service_stub, :list_org_policy_violations_previews, "org_policy_violations_previews", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
214 215 216 |
# File 'lib/google/cloud/policy_simulator/v1/org_policy_violations_preview_service/rest/client.rb', line 214 def logger @org_policy_violations_preview_service_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
133 134 135 |
# File 'lib/google/cloud/policy_simulator/v1/org_policy_violations_preview_service/rest/client.rb', line 133 def universe_domain @org_policy_violations_preview_service_stub.universe_domain end |